import { aws_ec2 as ec2 } from 'aws-cdk-lib';
/**
 * A class that manages the matching of ec2.Subnets with CIDR blocks.
 * Maintains two queues - one for CIDR blocks waiting to be assigned to subnets,
 * and another for subnets waiting to be assigned CIDR blocks.
 */
export declare class SubnetCidrBlockMatcher {
    /** Queue of CIDR blocks waiting to be assigned to subnets */
    private freshCidrBlocksAwaitingSubnet;
    /** Queue of subnets waiting to be assigned CIDR blocks */
    private subnetsAwaitingFreshCidrBlock;
    constructor();
    /**
     * Attempts to match a subnet with an available CIDR block.
     * If no CIDR block is available, adds the subnet to the waiting queue.
     * @param subnet The subnet to be matched with a CIDR block
     */
    matchSubnetWithCidrBlock(subnet: ec2.Subnet): void;
    /**
     * Attempts to match a CIDR block with a waiting subnet.
     * If no subnet is waiting, adds the CIDR block to the waiting queue.
     * @param cidrBlock The CIDR block to be matched with a subnet
     */
    matchFreshCidrBlockWithSubnet(cidrBlock: string): void;
}
